| Title: | Probabilistically Identify Clusters in Electronic Medical Records |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Michael DeWitt [aut, cre] (ORCID: <https://orcid.org/0000-0001-8940-1967>), Cone Health [aut, cph] |
| Maintainer: | Michael DeWitt <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-04-28 05:24:35 UTC |
| Source: | https://github.com/conedatascience/autotracer |
Simulated Patient Data Synthetic data that can be used to explore "autotracer"
autotracer_linelistautotracer_linelist
a data.frame with 10500 rows and 9 columns:
Latitude
Longitude
Race indentifier
Unique patient indentifier (e.g. MRN)
Age of the patient in years
Biological sex of the patient
Primary spoken language of the patient
Age given as a ten year age group
Date of test or infection identification
Probabilistically estimates a likely tranmission chain using EMR derrived data.
connect_probable_cases( dat, weights_in = NULL, threshold = 30, exposure_link = NULL )connect_probable_cases( dat, weights_in = NULL, threshold = 30, exposure_link = NULL )
dat |
the dataframe of likely connect cases with a column named "date" indicating the onset or positive test date and "patient_id", a unique identifier for the record. |
weights_in |
the weights to use for the serial interval if available |
threshold |
integer, the threshold in days at which to discard a connected case (e.g. >30 days from previous case, then discard). |
exposure_link |
string or column name, how these cases are connected |